# Changelog for `vimala`

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog], and this project adheres to
[Semantic Versioning].

[Keep a Changelog]: https://keepachangelog.com/en/1.0.0/
[Semantic Versioning]: https://semver.org/


## [Unreleased](https://github.com/bbugyi200/vimala/compare/0.1.0...HEAD)

No notable changes have been made.


## [0.1.0](https://github.com/bbugyi200/vimala/releases/tag/0.1.0) - 2022-01-15

### Miscellaneous

* First release.
